@@ -1,7 +1,7 @@
 # -*- encoding: utf-8; indent-tabs-mode: nil -*-
 #
 # Perl DateTime extension for providing French strings for the French Revolutionary calendar
-# Copyright (c) 2003, 2004, 2010, 2011, 2014, 2016 Jean Forget. All rights reserved.
+# Copyright (c) 2003, 2004, 2010, 2011, 2014, 2016, 2019 Jean Forget. All rights reserved.
 #
 # See the license in the embedded documentation below.
 #
@@ -13,7 +13,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '0.14'; # same as parent module DT::C::FR
+$VERSION = '0.15'; # same as parent module DT::C::FR
 
 my @months_short  = qw (Vnd Bru Fri Niv Plu Vnt Ger Flo Pra Mes The Fru S-C);
 #my @add_days_short= qw (Vertu Génie Trav Raison Récomp Révol);
@@ -57,10 +57,10 @@ my @feast = (
 # Vendémiaire
         qw(
        0raisin           0safran           1châtaigne        1colchique        0cheval
-       1balsamine        1carotte          2amarante         0panais           1cuve
+       1balsamine        1carotte          2amaranthe        0panais           1cuve
        1pomme_de_terre   2immortelle       0potiron          0réséda           2âne
-       1belle_de_nuit    1citrouille       0sarrasin         0tournesol        0pressoir
-       0chanvre          1pêche            0navet            2amaryllis        0bœuf
+       1belle-de-nuit    1citrouille       0sarrasin         0tournesol        0pressoir
+       0chanvre          1pêche            0navet            2amarillis        0bœuf
        2aubergine        0piment           1tomate           2orge             0tonneau
         ),
 # Brumaire
@@ -70,7 +70,7 @@ my @feast = (
        0salsifis         1macre            0topinambour      2endive           0dindon
        0chervis          0cresson          1dentelaire       1grenade          1herse
        1bacchante        2azerole          1garance          2orange           0faisan
-       1pistache         0macjon           0coing            0cormier          0rouleau
+       1pistache         0macjonc          0coing            0cormier          0rouleau
         ),
 # Frimaire
         qw(
@@ -93,7 +93,7 @@ my @feast = (
 # Pluviôse
         qw(
        1lauréole         1mousse           0fragon           0perce-neige      0taureau
-       0laurier-thym     2amadouvier       0mézéréon         0peuplier         1cognée
+       0laurier-thym     2amadouvier       0mézéréon         0peuplier         1coignée
        2ellébore         0brocoli          0laurier          2avelinier        1vache
        0buis             0lichen           2if               1pulmonaire       1serpette
        0thlaspi          0thymelé          0chiendent        1traînasse        0lièvre
@@ -102,9 +102,9 @@ my @feast = (
 # Ventôse
         qw(
        0tussilage        0cornouiller      0violier          0troène           0bouc
-       2asaret           2alaterne         1violette         0marsault         1bêche
+       2asaret           2alaterne         1violette         0marceau          1bêche
        0narcisse         2orme             1fumeterre        0vélar            1chèvre
-       2épinard          0doronic          0mouron           0cerfeuil         0cordeau
+       3épinards         0doronic          0mouron           0cerfeuil         0cordeau
        1mandragore       0persil           0cochléaria       1pâquerette       0thon
        0pissenlit        1sylvie           0capillaire       0frêne            0plantoir
         ),
@@ -120,19 +120,19 @@ my @feast = (
 # Floréal
         qw(
        1rose             0chêne            1fougère          2aubépine         0rossignol
-       2ancolie          0muguet           0champignon       1jacinthe         0rateau
+       2ancolie          0muguet           0champignon       1hyacinthe        0râteau
        1rhubarbe         0sainfoin         0bâton-d'or       0chamérisier      0ver_à_soie
        1consoude         1pimprenelle      1corbeille-d'or   2arroche          0sarcloir
-       0statice          1fritillaire      1bourrache        1valériane        1carpe
+       0staticé          1fritillaire      1bourrache        1valériane        1carpe
        0fusain           1civette          1buglosse         0sénevé           1houlette
         ),
 # Prairial
         qw(
-       1luzerne          2hémérocalle      0trèfle           2angélique        0canard
-       1mélisse          0fromental        0martagon         0serpolet         1faux
+       1luzerne          2hémérocale       0trèfle           2angélique        0canard
+       1mélisse          0fromental        0martagon         0serpolet         1faulx
        1fraise           1bétoine          0pois             2acacia           1caille
        2œillet           0sureau           0pavot            0tilleul          1fourche
-       0barbeau          1camomille        0chèvrefeuille    0caille-lait      1tanche
+       0barbeau          1camomille        0chèvre-feuille   0caille-lait      1tanche
        0jasmin           1verveine         0thym             1pivoine          0chariot
         ),
 # Messidor
@@ -141,26 +141,26 @@ my @feast = (
        0romarin          0concombre        2échalotte        2absinthe         1faucille
        1coriandre        2artichaut        1giroflée         1lavande          0chamois
        0tabac            1groseille        1gesse            1cerise           0parc
-       1menthe           0cumin            0haricot          2orcanète         1pintade
+       1menthe           0cumin            3haricots         2orcanète         1pintade
        1sauge            2ail              1vesce            0blé              1chalémie
         ),
 # Thermidor
         qw(
-       2épautre          0bouillon-blanc   0melon            2ivraie           0bélier
-       1prèle            2armoise          0carthame         1mûre             2arrosoir
+       2épeautre         0bouillon-blanc   0melon            2ivraie           0bélier
+       1prêle            2armoise          0carthame         1mûre             2arrosoir
        0panis            0salicor          2abricot          0basilic          1brebis
        1guimauve         0lin              2amande           1gentiane         2écluse
-       1carline          0câprier          1lentille         2aunée            1loutre
+       1carline          0caprier          1lentille         2aunée            1loutre
        1myrte            0colza            0lupin            0coton            0moulin
         ),
 # Fructidor
         qw(
-       1prune            0millet           0lycoperdon       2escourgeon       0saumon
+       1prune            0millet           0lycoperde        2escourgeon       0saumon
        1tubéreuse        0sucrion          2apocyn           1réglisse         2échelle
        1pastèque         0fenouil          2épine-vinette    1noix             1truite
        0citron           1cardère          0nerprun          0tagette          1hotte
        2églantier        1noisette         0houblon          0sorgho           2écrevisse
-       1bagarade         1verge-d'or       0maïs             0marron           0panier
+       1bigarade         1verge-d'or       0maïs             0marron           0panier
         ),
 # Jours complémentaires
         qw(
@@ -239,10 +239,10 @@ sub default_time_format      { $_[0]->time_formats->{ $_[0]->default_time_format
 
 sub _datetime_format_pattern_order { $_[0]->date_before_time ? (0, 1) : (1, 0) }
 
-sub    full_datetime_format { join ' ', ( $_[0]->full_date_format, $_[0]->full_time_format )[ $_[0]->_datetime_format_pattern_order ] }
-sub    long_datetime_format { join ' ', ( $_[0]->long_date_format, $_[0]->long_time_format )[ $_[0]->_datetime_format_pattern_order ] }
-sub  medium_datetime_format { join ' ', ( $_[0]->medium_date_format, $_[0]->medium_time_format )[ $_[0]->_datetime_format_pattern_order ] }
-sub   short_datetime_format { join ' ', ( $_[0]->short_date_format, $_[0]->short_time_format )[ $_[0]->_datetime_format_pattern_order ] }
+sub    full_datetime_format { join ' ', ( $_[0]->full_date_format,    $_[0]->full_time_format    )[ $_[0]->_datetime_format_pattern_order ] }
+sub    long_datetime_format { join ' ', ( $_[0]->long_date_format,    $_[0]->long_time_format    )[ $_[0]->_datetime_format_pattern_order ] }
+sub  medium_datetime_format { join ' ', ( $_[0]->medium_date_format,  $_[0]->medium_time_format  )[ $_[0]->_datetime_format_pattern_order ] }
+sub   short_datetime_format { join ' ', ( $_[0]->short_date_format,   $_[0]->short_time_format   )[ $_[0]->_datetime_format_pattern_order ] }
 sub default_datetime_format { join ' ', ( $_[0]->default_date_format, $_[0]->default_time_format )[ $_[0]->_datetime_format_pattern_order ] }
 
 sub default_date_format_length { $default_date_format_length }
@@ -1846,8 +1846,7 @@ du village de Roccavion.
 Koenigstein.
 
 1109
-9 Thermidor I Armée de Sambre et Meuse. Entrée des Français dans
-Liège.
+9 Thermidor I Armée de Sambre et Meuse. Entrée des Français dans Liège.
 
 9 Thermidor II La chute de Robespierre.
 
@@ -2286,7 +2285,7 @@ in any French History book or any encyclopedia.
 =head1 SUPPORT
 
 Support for this module is provided via the datetime@perl.org email
-list. See http://lists.perl.org/ for more details.
+list. See L<https://lists.perl.org/> for more details.
 
 =head1 AUTHOR
 
@@ -2299,25 +2298,82 @@ L<http://www.mongueurs.net/>.
 
 =head2 Books
 
-Calendrier Militaire, anonymous
+Calendrier Militaire, anonymous (see the last entry of the Internet section).
 
 =head2 Internet
 
-L<http://datetime.perl.org/>
+L<https://github.com/houseabsolute/DateTime.pm/wiki>
+
+L<https://en.wikipedia.org/wiki/French_Republican_Calendar>
+
+L<https://fr.wikipedia.org/wiki/Calendrier_républicain>
+
+L<https://archive.org/details/decretdelaconven00fran_40>
+
+"Décret  du  4 frimaire,  an  II  (24  novembre  1793) sur  l'ère,  le
+commencement et l'organisation de l'année et sur les noms des jours et
+des mois"
+
+L<https://archive.org/details/decretdelaconven00fran_41>
+
+Same text, with a slightly different typography.
+
+L<https://purl.stanford.edu/dx068ky1531>
+
+"Archives parlementaires  de 1789 à  1860: recueil complet  des débats
+législatifs & politiques  des Chambres françaises", J.  Madival and E.
+Laurent, et. al.,  eds, Librairie administrative de  P. Dupont, Paris,
+1912.
+
+Starting with  page 6,  this document  includes the  same text  as the
+previous links, with  a much improved typography.  Especially, all the
+"long s"  letters have been replaced  by short s. Also  interesting is
+the text  following the  decree, page 21  and following:  "Annuaire ou
+calendrier pour la seconde année de la République française, annexe du
+décret  du  4  frimaire,  an  II (24  novembre  1793)  sur  l'ère,  le
+commencement et l'organisation de l'année et sur les noms des jours et
+des mois".
+
+L<https://gallica.bnf.fr/ark:/12148/bpt6k48746z>
+
+[Fabre] "Rapport fait à la Convention nationale dans la séance du 3 du
+second mois de la seconde année  de la République française, au nom de
+la   Commission    chargée   de   la   confection    du   calendrier",
+Philippe-François-Nazaire  Fabre  d'Églantine,  Imprimerie  nationale,
+Paris, 1793
+
+L<https://gallica.bnf.fr/ark:/12148/bpt6k49016b>
+
+[Annuaire] "Annuaire  du cultivateur,  pour la  troisième année  de la
+République  : présenté  le  30 pluviôse  de l'an  II  à la  Convention
+nationale, qui en  a décrété l'impression et l'envoi,  pour servir aux
+écoles  de la  République",  Gilbert Romme,  Imprimerie nationale  des
+lois, Paris, 1794-1795
+
+L<https://gallica.bnf.fr/ark:/12148/bpt6k43978x>
+
+"Calendrier militaire,  ou tableau  sommaire des  victoires remportées
+par les  Armées de  la République française,  depuis sa  fondation (22
+septembre 1792),  jusqu'au 9  floréal an  7, époque  de la  rupture du
+Congrès de Rastadt et de la reprise des hostilités" Moutardier, Paris,
+An  VIII de  la République  française.  The source  of the  C<on_date>
+method.
+
 
 =head1 LICENSE STUFF
 
-Copyright (c)  2003, 2004,  2010, 2012, 2014,  2016 Jean  Forget.  All
-rights reserved.  This program is  free software. You  can distribute,
-modify,  and otherwise  mangle DateTime::Calendar::FrenchRevolutionary
-under the same terms as perl 5.16.3.
+Copyright (c)  2003, 2004, 2010,  2012, 2014, 2016, 2019  Jean Forget.
+All  rights  reserved.   This  program  is  free   software.  You  can
+distribute,         modify,        and         otherwise        mangle
+DateTime::Calendar::FrenchRevolutionary under  the same terms  as perl
+5.16.3.
 
 This program is  distributed under the same terms  as Perl 5.16.3: GNU
 Public License version 1 or later and Perl Artistic License
 
 You can find the text of the licenses in the F<LICENSE> file or at
-L<http://www.perlfoundation.org/artistic_license_1_0> and
-L<http://www.gnu.org/licenses/gpl-1.0.html>.
+L<https://dev.perl.org/licenses/artistic.html>
+and L<https://www.gnu.org/licenses/gpl-1.0.html>.
 
 Here is the summary of GPL:
 
@@ -2331,8 +2387,8 @@ WITHOUT   ANY  WARRANTY;   without  even   the  implied   warranty  of
 MERCHANTABILITY  or FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
 General Public License for more details.
 
-You  should have received  a copy  of the  GNU General  Public License
-along with this program; if not, see <http://www.gnu.org/licenses/> or
-write to the Free Software Foundation, Inc., L<http://fsf.org>.
+You should  have received  a copy  of the  GNU General  Public License
+along with  this program; if not,  see <https://www.gnu.org/licenses/>
+or write to the Free Software Foundation, Inc., L<https://www.fsf.org>.
 
 =cut
